==> xlniuxdata_gamepay_new-1.2-20151016.054506-4-sources.jar: com/xunlei/gamepay/bo/PaydetailokSumBoImpl.java <==
package com.xunlei.gamepay.bo;

import com.xunlei.common.util.PagedFliper;
import com.xunlei.common.util.Sheet;
import com.xunlei.gamepay.dao.IPaydetailokSumDao;
import com.xunlei.gamepay.vo.PayDetailOK;
import com.xunlei.gamepay.vo.PayDetailOKEachGamePaySumDTO;
import com.xunlei.gamepay.vo.PaydetailokSum;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class PaydetailokSumBoImpl extends BaseBo implements IPaydetailokSumBo {

	private IPaydetailokSumDao paydetailokSumDao;
	
	
	public IPaydetailokSumDao getPaydetailokSumDao() {
		return paydetailokSumDao;
	}


	public void setPaydetailokSumDao(IPaydetailokSumDao paydetailokSumDao) {
		this.paydetailokSumDao = paydetailokSumDao;
	}


	@Override
	public Sheet<PaydetailokSum> queryPaydetailokSumByUsername(PaydetailokSum data,
			PagedFliper fliper) {
		return this.getPaydetailokSumDao().query(data, fliper);
	}
	@Override
	public Sheet<PaydetailokSum> exportQueryPaydetailokSumByUsername(PaydetailokSum data,
			PagedFliper fliper) {
		return this.getPaydetailokSumDao().exportQuery(data, fliper);
	}

    @Override
    public Map<String, BigDecimal> getEachGamePaySum(PayDetailOK data) {
        List<PayDetailOKEachGamePaySumDTO> list =  this.getPaydetailokSumDao().getEachGamePaySum(data);
        Map<String,BigDecimal> map = new HashMap<String, BigDecimal>();
        for(PayDetailOKEachGamePaySumDTO dto:list){
            map.put(dto.getGameId(),new BigDecimal(dto.getPayMondey().toString()));
        }
        return map;
    }

}

==> xlniuxdata_gamepay_new-1.4.13-sources.jar: com/xunlei/gamepay/bo/PaydetailokSumBoImpl.java <==
package com.xunlei.gamepay.bo;

import com.xunlei.common.util.PagedFliper;
import com.xunlei.common.util.Sheet;
import com.xunlei.gamepay.dao.IPaydetailokSumDao;
import com.xunlei.gamepay.vo.PayDetailOK;
import com.xunlei.gamepay.vo.PayDetailOKEachGamePaySumDTO;
import com.xunlei.gamepay.vo.PaydetailokSum;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class PaydetailokSumBoImpl extends BaseBo implements IPaydetailokSumBo {

	private IPaydetailokSumDao paydetailokSumDao;
	
	
	public IPaydetailokSumDao getPaydetailokSumDao() {
		return paydetailokSumDao;
	}


	public void setPaydetailokSumDao(IPaydetailokSumDao paydetailokSumDao) {
		this.paydetailokSumDao = paydetailokSumDao;
	}


	@Override
	public Sheet<PaydetailokSum> queryPaydetailokSumByUsername(PaydetailokSum data,
			PagedFliper fliper) {
		return this.getPaydetailokSumDao().query(data, fliper);
	}
	@Override
	public Sheet<PaydetailokSum> exportQueryPaydetailokSumByUsername(PaydetailokSum data,
			PagedFliper fliper) {
		return this.getPaydetailokSumDao().exportQuery(data, fliper);
	}

    @Override
    public Map<String, BigDecimal> getEachGamePaySum(PayDetailOK data) {
        List<PayDetailOKEachGamePaySumDTO> list =  this.getPaydetailokSumDao().getEachGamePaySum(data);
        Map<String,BigDecimal> map = new HashMap<String, BigDecimal>();
        for(PayDetailOKEachGamePaySumDTO dto:list){
            map.put("0"+dto.getGameId(),new BigDecimal(dto.getPayMoney().toString()));
        }
        return map;
    }

	@Override
	public Sheet<PaydetailokSum> query4GameSum(PaydetailokSum data, PagedFliper fliper) {
		return paydetailokSumDao.query4GameSum(data,fliper);
	}

}
